/**
 * \file example_2.cpp
 * This is a simple example for using the ApMon structure. 
 * It illustrates the way to send to MonALISA an UDP datagram with a 
 * parameter and its value, using the sendParameter() and sendTimedParameter()
 *  functions.
 * The number of parameters that will be sent can be specified in the command 
 * line (if it is not, the default is 20). For each parameter value two 
 * datagrams are sent: one with a timestamp and one without a timestamp. For the
 * latter, the local time at the MonALISA host will be considered.
 */ 
#include <stdlib.h> 
#include <time.h>

#include "ApMon.h"
#include "utils.h"

using namespace apmon_utils;

int main(int argc, char **argv) {
  char *destList[2]= {"http://lcfg.rogrid.pub.ro/~corina/destinations_2.conf", 
		      "rb.rogrid.pub.ro password"};
  int nDatagrams = 20;
  char logmsg[100];
  double val = 0;
  int i, timestamp;

  if (argc ==2)
    nDatagrams = atoi(argv[1]);
  
   try {
    //ApMon *apm = new ApMon(2, destList);
    ApMon *apm = new ApMon("http://lcfg.rogrid.pub.ro/~corina/destinations_2.conf");
    apm -> setRecheckInterval(300);

    for (i = 0; i < nDatagrams; i++) {
      /* generate a value for the parameter  */
      val += 0.05;
      if (val > 2) 
	val = 0;
      sprintf(logmsg, "Sending %lf for cpu_load\n", val);
      logger(INFO, logmsg);

      /* use the wrapper function with simplified syntax */
     
      try {
	apm -> sendParameter("TestCluster2_cpp", NULL, "my_parameter", 
			  XDR_REAL64, (char *)&val);

	/* send a datagram with timestamp */
	timestamp = time(NULL) - (5 * 3600); // as if we sent the datagram 5 hours ago
	apm -> sendTimedParameter("TestClusterOld2_cpp", NULL, "my_parameter", 
			  XDR_REAL64, (char *)&val, timestamp) ;
      } catch(runtime_error &e) {
	logger(WARNING, e.what());
      }
    // test that we can stop the reloading thread  
    if (i == 15)
      apm -> setRecheckInterval(-1);
    sleep(2);
    } // for
    
    delete apm;
  } catch(runtime_error &e) {
    logger(WARNING, e.what());
  }
  
  return 0;
}
